/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Contact:  Sudipto Bal <sudipto.bal@samsung.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License")
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifndef __BM_BT_PLUGIN_H__
#define __BM_BT_PLUGIN_H__

#include <gmodule.h>
#include <time.h>
#include <bm_plugin_interface.h>

#ifdef __cplusplus
extern "C" {
#endif

/* this code is commented as common interface file
 * is placed in common/include directory (Abhishek)*/
#ifdef REDUNDANT_CODE
/*
 * alias for long data types
 */
typedef unsigned int		uint;
typedef unsigned char		uchar;

/*
 * battery-monitor data handle
 */
typedef void *bm_display_data_h;

/*
 * structure for application time map.
 */
typedef struct {
	char *app_id;		/* application id */
	uint time;		/* total duration for which application as active */
	uint rx;		/* Total Bytes received by the application during runtime */
	uint tx;		/* Total Bytes transmitted by the application during runtime */
} app_time_map_st2;

/*
 * structure for "bluetooth" feature data.
 */
typedef struct {
	uint scanTime;			/* Total time spent by the resource in (scan) mode during the session */
	uint connectedTime;		/* Total time spent by the resource in (connected) mode during the session */
	time_t startTime;		/* start time of feature data collection session */
	time_t stopTime;		/* stop time of feature data collection session */
	GSList *atm_list;		/* application time map('app_time_map_st2') list for all active applications between start & stop */
	GSList *bt_data_list;		/* list of nodes of 'bm_bluetooth_st' for next consecutive sessions */
} bm_bluetooth_st;
#endif

#ifdef __cplusplus
}
#endif

#endif /* __BM_BT_PLUGIN_H__ */
