/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License")
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifndef __BM_DISPLAY_PLUGIN_H__
#define __BM_DISPLAY_PLUGIN_H__

#include <gmodule.h>
#include <time.h>
#include <bm_plugin_interface.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
 * battery-monitor data handle
 */
typedef void *bm_display_data_h;

#ifdef ENABLE /* these structures are defined in common plugin interface */
/*
 * alias for long data types
 */
typedef unsigned int		uint;
typedef unsigned char		uchar;

/*
 * structure for application time map.
 */
typedef struct {
	char *app_id;			/* application id */
	uint time;			/* total duration for which application as active */
} app_time_map_st1;

/*
 * structure for "display" feature data.
 */
typedef struct {
	uint high;			/* time in milliseconds during which brightness intensity was high */
	uint low;			/* time in milliseconds during which brightness intensity was low */
	uint med;			/* time in milliseconds during which brightness intensity was medium */
	time_t start;			/* start time of feature data collection session */
	time_t stop;			/* stop time of feature data collection session */
	GSList *atm_list;		/* application time map('app_time_map_st') list for all active applications between start & stop */
	GSList *display_list;		/* list of nodes of 'bm_display_st' for next consecutive sessions */
} bm_display_st;
#endif /* end ENABLE */

#ifdef __cplusplus
}
#endif

#endif /* __BM_DISPLAY_PLUGIN_H__ */


