/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License")
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifndef __BM_WIFI_PLUGIN_H__
#define __BM_WIFI_PLUGIN_H__

#include <gmodule.h>
#include <time.h>
#include <bm_plugin_interface.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
 * battery-monitor data handle
 */
typedef void *bm_data_h;

#ifdef ENABLE /* these structures are defined in common plugin interface */
/*
 * alias for long data types
 */
typedef unsigned int		uint;
typedef unsigned char		uchar;

/*
 * structure for application time map.
 */
typedef struct {
	char *app_id;		/* application id */
	uint time;		/* total duration for which application as active */
	uint rx;		/* Total Bytes received by the application during runtime */
	uint tx;		/* Total Bytes transmitted by the application during runtime */
} app_time_map_st2;

/*
 * structure for "Wi-Fi" feature data.
 */
typedef struct {
	uint time_level_0;		/**< Total time in milliseconds during which rssi was on level 0 */
	uint time_level_1;		/**< Total time in milliseconds during which rssi was on level 1 */
	uint time_level_2;		/**< Total time in milliseconds during which rssi was on level 2 */
	uint time_level_3;		/**< Total time in milliseconds during which rssi was on level 3 */
	uint time_level_4;		/**< Total time in milliseconds during which rssi was on level 4 */
	time_t startTime;		/**< start time of feature data collection session */
	time_t endTime;			/**< end time of feature data collection session */
	uint scanTime;			/**< Total time spent by the resource in (scan) mode during the session */
	GSList *atm_list;		/**< application time map('app_time_map_st2') list for all active applications between start & stop */
	GSList *wifi_data_list;		/**< list of nodes of 'bm_wifi_st' for next consecutive sessions */
} bm_wifi_st;
#endif /* end ENABLE */

#ifdef __cplusplus
}
#endif

#endif /* __BM_WIFI_PLUGIN_H__ */


